@@ -24,7 +24,7 @@
 
 /* MONGOC_USER_SET_CFLAGS is set from config based on what compiler flags were
  * used to compile mongoc */
-#define MONGOC_USER_SET_CFLAGS "-march=armv6 -mfloat-abi=hard -mfpu=vfp -O2 -pipe -fstack-protector-strong -fno-plt"
+#define MONGOC_USER_SET_CFLAGS "-D_FORTIFY_SOURCE=2 -march=armv6 -mfloat-abi=hard -mfpu=vfp -O2 -pipe -fno-plt"
 
 #define MONGOC_USER_SET_LDFLAGS "-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now"
 
@@ -392,6 +392,15 @@
 #  undef MONGOC_HAVE_SS_FAMILY
 #endif
 
+/*
+ * Set if building with AWS IAM support.
+ */
+#define MONGOC_ENABLE_MONGODB_AWS_AUTH 1
+
+#if MONGOC_ENABLE_MONGODB_AWS_AUTH != 1
+#  undef MONGOC_ENABLE_MONGODB_AWS_AUTH
+#endif
+
 /*
  * NOTICE:
  * If you're about to update this file and add a config flag, make sure to
